==> stable20180905_135747.tar.gz: design/designer/src/com/fr/design/widget/ui/ListEditorDefinePane.java <==
package com.fr.design.widget.ui;

import javax.swing.*;

import com.fr.data.Dictionary;
import com.fr.design.data.DataCreatorUI;
import com.fr.design.gui.icheckbox.UICheckBox;
import com.fr.design.gui.ilable.UILabel;
import com.fr.design.layout.FRGUIPaneFactory;
import com.fr.design.mainframe.widget.accessibles.AccessibleDictionaryEditor;
import com.fr.form.ui.ListEditor;
import com.fr.general.Inter;

import java.awt.*;

public class ListEditorDefinePane extends WriteUnableRepeatEditorPane<ListEditor> {
	private UICheckBox needHeadCheckBox;
	private AccessibleDictionaryEditor dictPane;

	public ListEditorDefinePane() {
		this.initComponents();
	}

	@Override
	protected void initComponents() {
		super.initComponents();
	}

	protected Component[] createDicPane(){
		dictPane = new AccessibleDictionaryEditor();
		return new Component[]{new UILabel(Inter.getLocText("FR-Designer_DS-Dictionary")), dictPane};
	}


	@Override
	protected JPanel setThirdContentPane() {
		JPanel jPanel = FRGUIPaneFactory.createBorderLayout_S_Pane();
		needHeadCheckBox = new UICheckBox(Inter.getLocText("List-Need_Head"));
		needHeadCheckBox.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
		jPanel.add(needHeadCheckBox, BorderLayout.CENTER);
		jPanel.setBorder(BorderFactory.createEmptyBorder(10, 0, 0, 0));
		return jPanel;
	}
	
	@Override
	protected String title4PopupWindow() {
		return "List";
	}

	@Override
	protected void populateSubWriteUnableRepeatBean(ListEditor e) {
		needHeadCheckBox.setSelected(e.isNeedHead());
		this.dictPane.setValue(e.getDictionary());
	}

	@Override
	protected ListEditor updateSubWriteUnableRepeatBean() {
		ListEditor ob = new ListEditor();

		ob.setNeedHead(needHeadCheckBox.isSelected());
		ob.setDictionary((Dictionary) this.dictPane.getValue());

		return ob;
	}

    @Override
    public DataCreatorUI dataUI() {
        return null;
    }
}

==> stable20180907_091408.tar.gz: design/designer/src/com/fr/design/widget/ui/ListEditorDefinePane.java <==
package com.fr.design.widget.ui;

import javax.swing.JPanel;

import com.fr.design.data.DataCreatorUI;
import com.fr.design.gui.icheckbox.UICheckBox;
import com.fr.design.layout.FRGUIPaneFactory;
import com.fr.design.present.dict.DictionaryPane;
import com.fr.form.ui.ListEditor;
import com.fr.general.Inter;

public class ListEditorDefinePane extends WriteUnableRepeatEditorPane<ListEditor> {
	private UICheckBox needHeadCheckBox;
	private DictionaryPane dictPane;

	public ListEditorDefinePane() {
		this.initComponents();
	}

	@Override
	protected void initComponents() {
		super.initComponents();
		dictPane = new DictionaryPane();
	}

	@Override
	protected JPanel setThirdContentPane() {
		JPanel contenter = FRGUIPaneFactory.createBorderLayout_S_Pane();
		JPanel centerPane = FRGUIPaneFactory.createMediumHGapFlowInnerContainer_M_Pane();
		centerPane.add(needHeadCheckBox = new UICheckBox(Inter.getLocText("List-Need_Head")));
		contenter.add(centerPane);
		return contenter;
	}
	
	@Override
	protected String title4PopupWindow() {
		return "List";
	}

	@Override
	protected void populateSubWriteUnableRepeatBean(ListEditor e) {
		needHeadCheckBox.setSelected(e.isNeedHead());
		this.dictPane.populateBean(e.getDictionary());
	}

	@Override
	protected ListEditor updateSubWriteUnableRepeatBean() {
		ListEditor ob = new ListEditor();

		ob.setNeedHead(needHeadCheckBox.isSelected());
		ob.setDictionary(this.dictPane.updateBean());

		return ob;
	}

    @Override
    public DataCreatorUI dataUI() {
        return dictPane;
    }
}
